Interface: CoreInteractionOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: CoreInteractionOptions

## # Hierarchy

- `CoreInteractionOptions`

  ↳ `TooltipOptions`

## # Properties

### # axis

• axis: `InteractionAxis`

Defines which directions are used in calculating distances. Defaults to 'x' for 'index' mode and 'xy' in dataset and 'nearest' modes.

#### # Defined in

index.esm.d.ts:1439
(opens new window)

### # includeInvisible

• includeInvisible: `boolean`

if true, the invisible points that are outside of the chart area will also be included when evaluating interactions.

`default` false

#### # Defined in

index.esm.d.ts:1445
(opens new window)

### # intersect

• intersect: `boolean`

if true, the hover mode only applies when the mouse position intersects an item on the chart.

`default` true

#### # Defined in

index.esm.d.ts:1434
(opens new window)

### # mode

• mode: keyof `InteractionModeMap`

Sets which elements appear in the tooltip. See Interaction Modes for details.

`default` 'nearest'

#### # Defined in

index.esm.d.ts:1429
(opens new window)